@@ -18,4 +18,4 @@
 from .client import TargetdClient
 from .exceptions import TargetdException
 
-__all__ = [TargetdClient, TargetdException]
+__all__ = ["TargetdClient", "TargetdException"]
